==> purp-0.9.2.tar.gz: purp-0.9.2/main.h <==
/****************************************************************************
 This file is a part of Purp (Pugo RPM) - a ncurses-based RPM-handler
 Copyright (C) 1998-1999 -- Anders Karlsson <pugo@lysator.liu.se>

 This program is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
 the Free Software Foundation; either version 2 of the License, or
 (at your option) any later version.

 This program is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 GNU General Public License for more details.
 
 You should have received a copy of the GNU General Public License
 along with this program; if not, write to the Free Software
 Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.         
 
 For latest information and version of Purp, look at the Purp homepage:
 <http://www.lysator.liu.se/purp/>
 
 Please send comments and bug-reports to: <pugo@lysator.liu.se>
****************************************************************************/

#ifndef MAIN_H
#define MAIN_H

extern "C" { 
   #include <rpm/rpmlib.h>
} 

#define REAL_INSTALL 1
#define REAL_UNINSTALL 1

#define PURP_VERSION_STRING "PURP v0.9.2 -  1998-1999 Anders \"Pugo\" Karlsson"
#define PURP_DESCRIPTION_STRING " PURP (Pugo RPM) Version 0.9.2 - A ncurses-based RPM-handler \n"
#define PURP_COPYRIGHT_STRING " Copyright (C) 1998-1999 -- Anders Karlsson <pugo@lysator.liu.se>\n\n"

#define SIGSEGV_MESSAGE "Oops! Caught a SIGSEGV.. Shutting down.."
#define SIGHUP_MESSAGE  "Caught a SIGHUP.. Shutting down.."
#define SIGTERM_MESSAGE  "Caught a SIGKILL.. Shutting down!"

#define MINSIZE_MESSAGE "Purp needs a window of at least 60x14 to work!"

#define  INSTALLED_PANEL_TITLE   "Installed packages"
#define  AVAILABLE_PANEL_TITLE   "Available packages"

#define  LIBRPMALIAS_FILENAME "/usr/lib/rpmpopt"



void quitPurp( short, char * );
short ScanCommandLine( int, char ** );
void InterpretFlag( char **, int *, short *);
void PrintUsageInfo( void );
void InitRPM( void );
short purp_rpmdbOpen( rpmdb *db );

/* Signal handlers */
void sigSEGVhandler( int );
void sigHUPhandler( int );
void sigTERMhandler( int );
void sigWINCHhandler( int );

void resizeInterface( void );
void CheckResize( void );

#endif // MAIN_H

==> purp-0.9.5.tar.gz: purp-0.9.5/main.h <==
/****************************************************************************
 This file is a part of Purp (Pugo RPM) - a ncurses-based RPM-handler
 Copyright (C) 1998-2000 -- Anders Karlsson <pugo@pugo.org>

 This program is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
 the Free Software Foundation; either version 2 of the License, or
 (at your option) any later version.

 This program is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 GNU General Public License for more details.
 
 You should have received a copy of the GNU General Public License
 along with this program; if not, write to the Free Software
 Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.         
 
 For latest information and version of Purp, look at the Purp homepage:
 <http://www.lysator.liu.se/purp/>
 
 Please send comments and bug-reports to: <pugo@pugo.org>
****************************************************************************/

#ifndef MAIN_H
#define MAIN_H

extern "C" { 
   #include <rpm/rpmlib.h>
} 

#define REAL_INSTALL 1
#define REAL_UNINSTALL 1

#define PURP_VERSION_STRING "PURP v0.9.5 -  1998-2000 Anders \"Pugo\" Karlsson"
#define PURP_DESCRIPTION_STRING " PURP (Pugo RPM) Version 0.9.5 - A ncurses-based RPM-handler \n"
#define PURP_COPYRIGHT_STRING " Copyright (C) 1998-2000 -- Anders Karlsson <pugo@pugo.org>\n\n"

#define SIGSEGV_MESSAGE "Oops! Caught a SIGSEGV.. Shutting down.."
#define SIGHUP_MESSAGE  "Caught a SIGHUP.. Shutting down.."
#define SIGTERM_MESSAGE  "Caught a SIGKILL.. Shutting down!"

#define MINSIZE_MESSAGE "Purp needs a window of at least 60x14 to work!"

#define  INSTALLED_PANEL_TITLE   "Installed packages"
#define  AVAILABLE_PANEL_TITLE   "Available packages"

#define  LIBRPMALIAS_FILENAME "/usr/lib/rpmpopt"


void quitPurp( short, char * );
short ScanCommandLine( int, char ** );
void InterpretFlag( char **, int *, short *);
void PrintUsageInfo( void );
void InitRPM( void );
short purp_rpmdbOpen( rpmdb *db );

/* Signal handlers */
void sigSEGVhandler( int );
void sigHUPhandler( int );
void sigTERMhandler( int );
void sigWINCHhandler( int );

void resizeInterface( void );
void CheckResize( void );

#endif // MAIN_H
